/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner

import com.google.gson.annotations.SerializedName
import com.kakao.sdk.common.util.KakaoJson

/**
 * 카카오 Deploy Phase 를 나타냅니다. 원하는 Phase를 파라미터로 전달하여 [ServerHosts] 를 생성하고 [KakaoSdk.init] [init] 을 호출합니다.
 *
 * ```kotlin
 * // Sandbox 설정 예제
 * KakaoSdk.init(
 *   context,
 *   appKey,
 *   ServerHosts.withPhase(KakaoPhase.SANDBOX)
 * )
 * ```
 */
enum class KakaoPhase(val phaseName: String) {
    @SerializedName("dev")
    DEV("dev"),
    @SerializedName("sandbox")
    SANDBOX("sandbox"),
    @SerializedName("cbt")
    CBT("cbt"),
    @SerializedName("production")
    PRODUCTION("production");

    companion object {
        /**
         * @suppress
         */
        fun fromName(value: String) = KakaoJson.fromJson<KakaoPhase>(value, KakaoPhase::class.java)
    }
}